@@ -36,8 +36,8 @@ train.default <- function(x, y,
                                       "either 0 or 1"))
     }
 
-  if(!is.null(preProcess) && !(all(preProcess %in% c("center", "scale", "pca", "ica", "BoxCox", "spatialSign", "knnImpute", "bagImpute")))) 
-    stop('pre-processing methods are limited to center, scale, pca, ica, knnImpute, bagImpute and spatialSign')
+  if(!is.null(preProcess) && !(all(preProcess %in% c("center", "scale", "pca", "ica", "BoxCox", "spatialSign", "knnImpute", "bagImpute", "range")))) 
+    stop('pre-processing methods are limited to center, scale, range, pca, ica, knnImpute, bagImpute and spatialSign')
 
   
   if(modelType == "Classification")
@@ -70,6 +70,10 @@ train.default <- function(x, y,
           warning("Class probabilities were requested for a model that does not implement them")
           trControl$classProbs <- FALSE
         }
+      if(method %in% c("svmLinear", "svmRadial", "svmPoly") & any(names(list(...)) == "class.weights"))
+         warning("since class weights are requested, SVM class probabilities cannot be generated")
+         
+         
     } else {
       if(!any(modelInfo$forReg)) stop("wrong model type for regression")
       if(metric %in% c("Accuracy", "Kappa")) 
@@ -128,9 +132,18 @@ train.default <- function(x, y,
             {
               tuneGrid <- tuneGrid(tuneLength, trainData)
             } else stop("If a function, tuneGrid should have arguments len and data")
+        } else {
+          ## Check tuneing parameter names
+          tuneNames <- modelLookup(method)$parameter
+          tuneNames <- paste(".", sort(tuneNames), sep = "")
+          goodNames <- all.equal(tuneNames, sort(names(tuneGrid)))
+          if(!is.logical(goodNames) || !goodNames)
+            stop(paste("The tuning parameter grid must have columns",
+                       paste(tuneNames, collapse = ", ")))
         }
     }
 
+
   ##------------------------------------------------------------------------------------------------------------------------------------------------------#
 
   ## For each tuning parameter combination, we will loop over them, fit models and generate predictions.
